---
layout: assignment
published: true

title: Disability Justice Analysis
description: Analyze an article using a disability justice framework
code: hw2

assigned: 
    - October 4th, 2023
due: 
    - October 9th, 2023, 3:30pm (Two day grace period, October 11th)

revised: August 20, 2023

---
* TOC
{:toc}

# Overview 

The goal of this homework is to apply a disability justice framework to analyzing a technology or service currently in use in the world. 

## Learning Goals / Competencies
This homework may contribute to 
- Your competency grade on following [best practices for plain language writing](https://www.plainlanguage.gov/guidelines/) in your post
- Your competency grade on understanding how to apply a disability justice framing
- Your participation grade, as a percentage of completeness (are all the required parts present)

## Length & Difficulty
Students in the past have reported that this assignment takes an median of 4 hours (mode=3). However, in our experience many students have to make multiple attempts to fully meet the competency for disability justice. It is recommended to carefully read about the 10 principals and ask questions if you are having trouble understanding which one might apply. 
Some things students have told us about this assignment:
- "Writing well in Plain language is harder than I thought."
- it is sometimes hard to identify a remedy. Again, reach out if you need help here.

# Details

To complete this assignment, you will need to do the following

## 0. Learn about plain language
Read about [plain language writing for accessibility](https://www.forbes.com/sites/andrewpulrang/2020/10/22/plain-language-writing---an-essential-part-of-accessibility/?sh=4afd8af77935) and [plain language guidelines](https://www.med.unc.edu/healthsciences/clds/wp-content/uploads/sites/859/2021/06/Minimized-Text-Complexity-Guidelines-version-2.03.2021.pdf)

## 1. Read and summarize article on the topic you have selected. 
You may use one of the articles we have provided (see below) or find one of your own (requires instructor approval). Your summary should be about a paragraph long (250 words).

{% details Possible readings %}
- [masking and disability justice](https://www.thecrimson.com/article/2022/4/21/mask-mandate-disability-justice/) "The most frustrating part that I've had conversations about with people who don’t want the mask mandate has just been me being like, 'I have this condition. I would basically die if I got COVID,'" Shang says. “And then people are like, ‘Yeah, but that’s your issue, not ours.'"
- [public health and disability justice](https://disabilityvisibilityproject.com/2022/03/07/disabled-people-are-tired-public-health-and-ableism/) "It is clear that the only way out of a global pandemic is collectivity, not individualism, but how are disabled people expected to hand our lives over to a collective that doesn’t seem to care if people like us live or die?"
- [the school to prison pipeline](https://ncd.gov/publications/2015/06182015/) "Studies show that up to 85 percent of youth in juvenile detention facilities have disabilities that make them eligible for special education services, yet only 37 percent receive these services while in school.  A disproportionate percentage of these detained youth are youth of color.  These statistics should lead to the conclusion that many disabled youth in the juvenile justice and criminal justice systems are deprived of an appropriate education that could have changed their School-to-Prison Pipeline trajectory."
- [policing and disability](https://www.theatlantic.com/health/archive/2014/05/misunderstanding-disability-leads-to-police-violence/361786/) and [policing and autism](https://chicagoreader.com/news-politics/black-autistic-and-killed-by-police/) "People with an autism spectrum disorder are seven times more likely to encounter police than “neurotypical” individuals, or those without developmental disabilities, according to autism experts. Depending on the severity of their disorder, people on the autism spectrum can react inappropriately to police and have trouble following commands."
- [disability in  prison](http://avidprisonproject.org/Making-Hard-Time-Harder/) "A prison sentence shouldn't be harder, it shouldn't be longer, and conditions of confinement shouldn't be harsher simply because of a disability."
- [disability and sex work](http://titsandsass.com/having-the-option-alissa-afonina-on-her-case-and-being-a-disabled-sex-worker/) and [disability and sexuality](https://www.theatlantic.com/health/archive/2015/03/sex-and-disability/386866/) "When you are disabled, the two things people think you can’t do are fight and have sex. So I’ve got a black belt and I’m really good at shagging."
- [disability and activism](https://everydayfeminism.com/2016/09/social-justice-activism-ableist/)
- [the right to be rescued](https://rootedinrights.org/video/therighttoberescued/) and [disability and disaster response](https://www.un.org/development/desa/disabilities/issues/disability-inclusive-disaster-risk-reduction-and-emergency-situations.html) "persons with disabilities are more likely to be left behind or abandoned during evacuation in disasters and conflicts due to a lack of preparation and planning, as well as inaccessible facilities and services and transportation systems. Most shelters and refugee camps are not accessible and people with disabilities are many times even turned away from shelters and refugees camps due to a perception that they need “complex medical” services. Disruption to physical, social, economic, and environmental networks and support systems affect persons with disabilities much more than the general population. There is also a potential for discrimination on the basis of disability when resources are scarce. Furthermore, the needs of persons with disabilities continue to be excluded over the more long-term recovery and reconstruction efforts, thus missing another opportunity to ensure that cities are accessible and inclusively resilient to future disasters."
- [algorithmic healthcare](https://www.theverge.com/2018/3/21/17144260/healthcare-medicaid-algorithm-arkansas-cerebral-palsy) "Dobbs’ situation hadn’t improved, but an invisible change had occurred. When the assessor entered Dobbs’ information into the computer, it ran through an algorithm that the state had recently approved, determining how many hours of help she would receive.... The change left Dobbs in a situation she never thought she would be in, as the program she’d relied on for years fell out from below her."
- [access versus cures](https://www.youtube.com/watch?v=7LHNwzLa-88) "is medicine about quality of life or is it about social control?"
- [intimacy](https://leavingevidence.wordpress.com/2017/08/06/forced-intimacy-an-ableist-norm/) "Forced Intimacy” is a term I have been using for years to refer to the common, daily experience of disabled people being expected to share personal parts of ourselves to survive in an ableist world. This often takes the form of being expected to share (very) personal information with able bodied people to get basic access, but it also includes forced physical intimacy, especially for those of us who need physical help that often requires touching of our bodies."
- [accessibe](https://www.vice.com/en/article/m7az74/people-with-disabilities-say-this-ai-tool-is-making-the-web-worse-for-them) "They’re actively marketing ‘Hey, don’t worry about it, don’t worry about learning about accessibility—use our automated tool. And not only does the automated tool not fix things, but it gives companies a reason not to educate their coders,” Chancey Fleet, president of the National Federation of the Blind’s assistive technology trainers division, told Motherboard. (Optional  [related article](https://www.linkedin.com/pulse/lies-damned-overlays-widgets-timothy-springer/))
{% enddetails %}


## 3. Select and write about 3 Disability Justice Principles 

Select at least 3 of the [10 principles of disability justice](https://static1.squarespace.com/static/5bed3674f8370ad8c02efd9a/t/5f1f0783916d8a179c46126d/1595869064521/10_Principles_of_DJ-2ndEd.pdf), and reflect on the ways in which this technology or service addresses, or fails to address, those principals.

Please note that the principals of disability justice are political in nature -- that is an important reason we let you select among them. Wthether you agree with them or not, we are asking you to demonstrate your understanding what the disability community has put forth in defining these principals. 

For each principle, write 1-2 paragraphs (250-500 words). In your writing, you should  name it, briefly define it, and explain how it relates to the article. In addition, explain what remedy could improve the justice of this technology or service (or explain why you believe no remedy is needed). 


# Turnin
You will need to submit your writeup to the class [discussion board]({{site.discussion}}). The category should be "Assignments", the subcategory should be "Disability Justice". Also submit a link to your discussion board post on {{site.canvas}}.

